==> risk-center-api-0.4.20-20190109.024000-2-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/AdvertWhiteListDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

/**
 * 广告计划白名单
 */
@ApiModel
public class AdvertWhiteListDto implements Serializable {

    private static final long serialVersionUID = -7990788453435257723L;

    private Long id;

    @ApiModelProperty("广告计划id")
    private Long advertId;

    @ApiModelProperty("广告名称")
    private String advertName;

    @ApiModelProperty("广告主名称")
    private String advertMaster;

    @ApiModelProperty("名单场景 0-落地页返回拦截, 1-落地页篡改")
    private Integer sceneType;

    @ApiModelProperty("创建人")
    private String creator;

    @ApiModelProperty("创建时间")
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertMaster(String advertMaster) {
        this.advertMaster = advertMaster;
    }

    public String getAdvertMaster() {
        return advertMaster;
    }

    public void setSceneType(Integer sceneType) {
        this.sceneType = sceneType;
    }

    public Integer getSceneType() {
        return sceneType;
    }

    public void setCreator(String creator) {
        this.creator = creator;
    }

    public String getCreator() {
        return creator;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

}

==> risk-center-api-0.4.24-20190201.084609-3-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/AdvertWhiteListDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.Date;

/**
 * 广告计划白名单
 */
@ApiModel
public class AdvertWhiteListDto implements Serializable {

    private static final long serialVersionUID = -7990788453435257723L;

    private Long id;

    @ApiModelProperty("广告计划id")
    private Long advertId;

    @ApiModelProperty("广告名称")
    private String advertName;

    @ApiModelProperty("广告主名称")
    private String advertMaster;

    @ApiModelProperty("名单场景 0-落地页返回拦截, 1-落地页篡改")
    private Integer sceneType;

    @ApiModelProperty("创建人")
    private String creator;

    @ApiModelProperty("备注")
    private String description;

    @ApiModelProperty("创建时间")
    private Date gmtCreate;

    @ApiModelProperty("更新时间")
    private Date gmtModified;

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertMaster(String advertMaster) {
        this.advertMaster = advertMaster;
    }

    public String getAdvertMaster() {
        return advertMaster;
    }

    public void setSceneType(Integer sceneType) {
        this.sceneType = sceneType;
    }

    public Integer getSceneType() {
        return sceneType;
    }

    public void setCreator(String creator) {
        this.creator = creator;
    }

    public String getCreator() {
        return creator;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

}
